# NetworkProtocolAllOf


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**dhcp_pool** | [**DHCPPool**](DHCPPool.md) |  | [optional] 
**dns_settings** | **str** |  | [optional] 
**ntp_settings** | **[str]** |  | [optional] 
**nat_rules** | [**[NATRule]**](NATRule.md) |  | [optional] 
**ntp_inherit** | **bool** |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


